<?php
/**
 * Featured section
 *
 * This is the template for the content of featured section
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */
if ( ! function_exists( 'personify_add_featured_section' ) ) :
    /**
    * Add featured section
    *
    *@since Personify 0.1
    */
    function personify_add_featured_section() {
        // Check if featured is enabled on frontpage
        $featured_enable = apply_filters( 'personify_section_status', true, 'featured_section_enable' );

        if ( true !== $featured_enable ) {
            return false;
        }
        // Get featured section details
        $section_details = array();
        $section_details = apply_filters( 'personify_filter_featured_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured section now.
        personify_render_featured_section( $section_details );
    }
endif;
add_action( 'personify_primary_content', 'personify_add_featured_section', 30 );


if ( ! function_exists( 'personify_get_featured_section_details' ) ) :
    /**
    * featured section details.
    *
    * @since Personify 0.1
    * @param array $input featured section details.
    */
    function personify_get_featured_section_details( $input ) {
        $options = personify_get_theme_options();

        $content = array();

        $cat_id = ! empty( $options['featured_content_category'] ) ? $options['featured_content_category'] : '';
        $args = array(
            'post_type'         => 'post',
            'cat'               => absint( $cat_id ),
            'posts_per_page'    => 3,
            );                    

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['excerpt']   = personify_trim_content( 25 );
                $page_post['url']       = get_the_permalink();

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured section content details.
add_filter( 'personify_filter_featured_section_details', 'personify_get_featured_section_details' );


if ( ! function_exists( 'personify_render_featured_section' ) ) :
  /**
   * Start featured section
   *
   * @return string featured content
   * @since Personify 0.1
   *
   */
   function personify_render_featured_section( $content_details = array() ) {
        $options = personify_get_theme_options();
        $read_more = ! empty( $options['read_more_text'] ) ? $options['read_more_text'] : esc_html__( 'Read', 'personify' );
        $featured_image     = ! empty( $options['featured_image'] ) ? $options['featured_image'] : '';
        $class = ( empty( $featured_image ) ) ? ' no-featured-image' : '';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="latest-posts" class="relative<?php echo esc_attr( $class ); ?>">
            <div class="wrapper">
                <div class="section-content clear">
                    <div class="posts-wrapper">
                        <?php foreach( $content_details as $content ) : ?>
                            <article class="hentry">

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content"><?php echo esc_html( $content['excerpt'] ); ?></div><!-- .entry-content -->

                                <span class="read-more">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $read_more ); ?></a>
                                </span><!-- .read-more -->
                            </article>
                        <?php endforeach; ?>
                    </div><!-- .posts-wrapper -->
                    <?php if ( ! empty( $featured_image ) ) : ?>
                        <div class="featured-image-wrapper">
                            <div class="featured-image" style="background-image: url('<?php echo esc_url( $featured_image ); ?>');">
                            </div><!-- .featured-image -->
                        </div><!-- .featured-image-wrapper -->
                    <?php endif; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- #latest-posts -->
    <?php }
endif;