<?php
/**
 * Message section
 *
 * This is the template for the content of message section
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */
if ( ! function_exists( 'personify_add_message_section' ) ) :
    /**
    * Add message section
    *
    *@since Personify 0.1
    */
    function personify_add_message_section() {
        // Check if message is enabled on frontpage
        $message_enable = apply_filters( 'personify_section_status', true, 'message_section_enable' );

        if ( true !== $message_enable ) {
            return false;
        }
        // Get message section details
        $section_details = array();
        $section_details = apply_filters( 'personify_filter_message_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render message section now.
        personify_render_message_section( $section_details );
    }
endif;
add_action( 'personify_primary_content', 'personify_add_message_section', 70 );


if ( ! function_exists( 'personify_get_message_section_details' ) ) :
    /**
    * message section details.
    *
    * @since Personify 0.1
    * @param array $input message section details.
    */
    function personify_get_message_section_details( $input ) {
        $options = personify_get_theme_options();

        $content = array();
        $page_id = ! empty( $options['message_content_page'] ) ? $options['message_content_page'] : '';
        $args = array(
            'post_type'         => 'page',
            'page_id'           => $page_id,
            'posts_per_page'    => 1,
            );

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['excerpt']   = get_the_content();

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();


        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// message section content details.
add_filter( 'personify_filter_message_section_details', 'personify_get_message_section_details' );


if ( ! function_exists( 'personify_render_message_section' ) ) :
  /**
   * Start message section
   *
   * @return string message content
   * @since Personify 0.1
   *
   */
   function personify_render_message_section( $content_details = array() ) {
        $options = personify_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        }
        foreach ( $content_details as $content ) : ?>
            <div id="section-promotion" class="relative page-section">
                <div class="wrapper">
                    <div class="entry-content">
                        <p class="description">
                            <?php echo wp_kses_post( $content['excerpt'] ); ?>
                        </p>
                    </div><!-- .entry-content -->
                    <div class="separator"></div>
                </div><!-- .wrapper -->
            </div><!-- #section-promotion -->
        <?php endforeach; 
    }
endif;