<?php
/**
 * Quotation section
 *
 * This is the template for the content of quotation section
 *
 * @package Theme Palace
 * @subpackage Personify
 * @since Personify 0.1
 */
if ( ! function_exists( 'personify_add_quotation_section' ) ) :
    /**
    * Add quotation section
    *
    *@since Personify 0.1
    */
    function personify_add_quotation_section() {
        // Check if quotation is enabled on frontpage
        $quotation_enable = apply_filters( 'personify_section_status', true, 'quotation_section_enable' );

        if ( true !== $quotation_enable ) {
            return false;
        }
        // Get quotation section details
        $section_details = array();
        $section_details = apply_filters( 'personify_filter_quotation_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render quotation section now.
        personify_render_quotation_section( $section_details );
    }
endif;
add_action( 'personify_primary_content', 'personify_add_quotation_section', 40 );


if ( ! function_exists( 'personify_get_quotation_section_details' ) ) :
    /**
    * quotation section details.
    *
    * @since Personify 0.1
    * @param array $input quotation section details.
    */
    function personify_get_quotation_section_details( $input ) {
        $options = personify_get_theme_options();

        $content = array();
        $page_id = ! empty( $options['quotation_content_page'] ) ? $options['quotation_content_page'] : '';

        $args = array(
            'post_type'         => 'page',
            'page_id'           => $page_id,
            'posts_per_page'    => 1,
            );

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['excerpt']   = get_the_content();

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();


        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// quotation section content details.
add_filter( 'personify_filter_quotation_section_details', 'personify_get_quotation_section_details' );


if ( ! function_exists( 'personify_render_quotation_section' ) ) :
  /**
   * Start quotation section
   *
   * @return string quotation content
   * @since Personify 0.1
   *
   */
   function personify_render_quotation_section( $content_details = array() ) {
        $options = personify_get_theme_options();

        if ( empty( $content_details ) ) {
            return;
        } ?>
            <div id="feedback-section" class="relative page-section">
                <div class="wrapper">
                    <div class="section-content">
                        <?php echo personify_get_svg( array( 'icon' => 'quote' ) ); ?>
                        <div class="speaker-quote" data-slick='{"slidesToShow": 1, "slidesToScroll": 1, "infinite": true, "speed": 1200, "dots": true, "arrows":false, "autoplay": true, "fade": false, "draggable": true }'>
                             <?php foreach ( $content_details as $content ) : ?>
                                <div class="slick-item">
                                    <div class="entry-content">
                                        <?php echo wp_kses_post( $content['excerpt'] ); ?>
                                    </div><!-- .entry-content -->
                                </div><!-- .slick-item -->
                            <?php endforeach; ?>
                        </div><!-- .regular -->
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #feedback-section -->
    <?php }
endif;